==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/realm/entity/MapOTPPolicyEntityFields.java <==
package org.keycloak.models.map.realm.entity;
public enum MapOTPPolicyEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> {
    OTP_POLICY_ALGORITHM {
        public static final String FIELD_NAME = "OtpPolicyAlgorithm";
        public static final String FIELD_NAME_DASHED = "otp-policy-algorithm";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (String) e.getOtpPolicyAlgorithm();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyAlgorithm((String) value);
        }
    },
    OTP_POLICY_CODE_REUSABLE {
        public static final String FIELD_NAME = "OtpPolicyCodeReusable";
        public static final String FIELD_NAME_DASHED = "otp-policy-code-reusable";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyCodeReusable((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Boolean) e.isOtpPolicyCodeReusable();
        }
    },
    OTP_POLICY_DIGITS {
        public static final String FIELD_NAME = "OtpPolicyDigits";
        public static final String FIELD_NAME_DASHED = "otp-policy-digits";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Integer) e.getOtpPolicyDigits();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyDigits((Integer) value);
        }
    },
    OTP_POLICY_INITIAL_COUNTER {
        public static final String FIELD_NAME = "OtpPolicyInitialCounter";
        public static final String FIELD_NAME_DASHED = "otp-policy-initial-counter";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyInitialCounter((Integer) value);
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Integer) e.getOtpPolicyInitialCounter();
        }
    },
    OTP_POLICY_LOOK_AHEAD_WINDOW {
        public static final String FIELD_NAME = "OtpPolicyLookAheadWindow";
        public static final String FIELD_NAME_DASHED = "otp-policy-look-ahead-window";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyLookAheadWindow((Integer) value);
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Integer) e.getOtpPolicyLookAheadWindow();
        }
    },
    OTP_POLICY_PERIOD {
        public static final String FIELD_NAME = "OtpPolicyPeriod";
        public static final String FIELD_NAME_DASHED = "otp-policy-period";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyPeriod((Integer) value);
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Integer) e.getOtpPolicyPeriod();
        }
    },
    OTP_POLICY_TYPE {
        public static final String FIELD_NAME = "OtpPolicyType";
        public static final String FIELD_NAME_DASHED = "otp-policy-type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (String) e.getOtpPolicyType();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyType((String) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapOTPPolicyEntityFields.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapOTPPolicyEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.realm.entity.MapOTPPolicyEntity> {
    OTP_POLICY_ALGORITHM {
        public static final String FIELD_NAME = "OtpPolicyAlgorithm";
        public static final String FIELD_NAME_DASHED = "otp-policy-algorithm";
        public static final String FIELD_NAME_CAMEL_CASE = "otpPolicyAlgorithm";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyAlgorithm((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (String) e.getOtpPolicyAlgorithm();
        }
    },
    OTP_POLICY_CODE_REUSABLE {
        public static final String FIELD_NAME = "OtpPolicyCodeReusable";
        public static final String FIELD_NAME_DASHED = "otp-policy-code-reusable";
        public static final String FIELD_NAME_CAMEL_CASE = "otpPolicyCodeReusable";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyCodeReusable((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Boolean) e.isOtpPolicyCodeReusable();
        }
    },
    OTP_POLICY_DIGITS {
        public static final String FIELD_NAME = "OtpPolicyDigits";
        public static final String FIELD_NAME_DASHED = "otp-policy-digits";
        public static final String FIELD_NAME_CAMEL_CASE = "otpPolicyDigits";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyDigits((Integer) value);
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Integer) e.getOtpPolicyDigits();
        }
    },
    OTP_POLICY_INITIAL_COUNTER {
        public static final String FIELD_NAME = "OtpPolicyInitialCounter";
        public static final String FIELD_NAME_DASHED = "otp-policy-initial-counter";
        public static final String FIELD_NAME_CAMEL_CASE = "otpPolicyInitialCounter";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Integer) e.getOtpPolicyInitialCounter();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyInitialCounter((Integer) value);
        }
    },
    OTP_POLICY_LOOK_AHEAD_WINDOW {
        public static final String FIELD_NAME = "OtpPolicyLookAheadWindow";
        public static final String FIELD_NAME_DASHED = "otp-policy-look-ahead-window";
        public static final String FIELD_NAME_CAMEL_CASE = "otpPolicyLookAheadWindow";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Integer) e.getOtpPolicyLookAheadWindow();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyLookAheadWindow((Integer) value);
        }
    },
    OTP_POLICY_PERIOD {
        public static final String FIELD_NAME = "OtpPolicyPeriod";
        public static final String FIELD_NAME_DASHED = "otp-policy-period";
        public static final String FIELD_NAME_CAMEL_CASE = "otpPolicyPeriod";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Integer.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyPeriod((Integer) value);
        }
        @SuppressWarnings("unchecked") @Override public Integer get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (Integer) e.getOtpPolicyPeriod();
        }
    },
    OTP_POLICY_TYPE {
        public static final String FIELD_NAME = "OtpPolicyType";
        public static final String FIELD_NAME_DASHED = "otp-policy-type";
        public static final String FIELD_NAME_CAMEL_CASE = "otpPolicyType";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e) {
            return (String) e.getOtpPolicyType();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.realm.entity.MapOTPPolicyEntity e, T value) {
            e.setOtpPolicyType((String) value);
        }
    },
}
